/*
 * Copyright (c) 2002 World Wide Web Consortium,
 * (Massachusetts Institute of Technology, Institut National de
 * Recherche en Informatique et en Automatique, Keio University). All
 * Rights Reserved. This program is distributed under the W3C's Software
 * Intellectual Property License. This program is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.
 * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
 */

package org.w3c.dom;

/**
 *  The <code>TypeInfo</code> interface represent a type used by 
 * <code>Element</code> or <code>Attr</code> nodes, specified in the schemas 
 * associated with the document. The type is a pair of a namespace URI and 
 * name properties, and depends on the document's schema.  should you be 
 * able to return <code>null</code> on <code>name</code>? for anonymous 
 * type? for undeclared elements/attributes? Can schemaType be 
 * <code>null</code>? 
 * <p> If the document's schema is an XML DTD [<a href='http://www.w3.org/TR/2000/REC-xml-20001006'>XML 1.0</a>], the values are computed as 
 * follows:  If this type is referenced from an <code>Attr</code> node, 
 * <code>namespace</code> is <code>null</code> and <code>name</code> 
 * represents the property the [attribute type] property in the [<a href='http://www.w3.org/TR/2001/REC-xml-infoset-20011024/'>XML Information set</a>]. If there 
 * is no declaration for the attribute, <code>name</code> is 
 * <code>null</code>.  Unlike for XML Schema, the name contain the declared 
 * type, and does not relate to "validity".  If this type is referenced from 
 * an <code>Element</code> node, the <code>namespace</code> and 
 * <code>name</code> are <code>null</code>. 
 * <p> If the document's schema is an XML Schema [<a href='http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/'>XML Schema Part 1</a>], the values are computes as 
 * follows:  If the [validity] property defined in the PSVI (Post-Schema 
 * Validation Infoset) contributions to element and attribute information 
 * items is invalid or notKnown:  If the type is referenced from an 
 * <code>Element</code> node, <code>namespace</code> is 
 * <code>"http://www.w3.org/2001/XMLSchema"</code> and <code>name</code> is 
 * <code>"anyType"</code>, as defined in Complex Type Definition of the 
 * Ur-Type in [<a href='http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/'>XML Schema Part 1</a>].  If the type is referenced from an <code>Attr</code> node, 
 * <code>namespace</code> is <code>"http://www.w3.org/2001/XMLSchema"</code> 
 * and <code>name</code> is <code>"anySimpleType"</code>, as defined in 
 * Simple Type Definition of the Ur-Type in [<a href='http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/'>XML Schema Part 1</a>].  if invalid, should this be 
 * xs:anyType/anySimpleType? should we return the declared type instead? 
 * what union in that case?  If the [validity] property defined in the PSVI 
 * contributions to element and attribute information items is valid and if 
 * [type definition anonymous] or [member type definition anonymous] is 
 * <code>true</code>, this specification does not define how to expose 
 * anonymous types.  If the [validity] property defined in the PSVI 
 * contributions to element and attribute information items is valid and if 
 * [type definition anonymous] or [member type definition anonymous] is 
 * <code>false</code>:  If the [type definition] has union as defined in [<a href='http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/'>XML Schema Part 1</a>], 
 * then the <code>name</code> and the <code>namespace</code> correspond 
 * respectively to the [member type definition name] and [member type 
 * definition namespace] properties defined in the PSVI contributions to 
 * element and attribute information items.  Otherwise, the <code>name</code>
 *  and the <code>namespace</code> correspond to the [type definition name] 
 * and [type definition namespace] properties defined in the PSVI 
 * contributions to element and attribute information items.  Other schema 
 * languages are outside the scope of the W3C and therefore should define 
 * how to represent their type systems using <code>TypeInfo</code>. 
 * <p>See also the <a href='http://www.w3.org/TR/2002/WD-DOM-Level-3-Core-20021022/'>Document Object Model (DOM) Level 3 Core Specification</a>.
 * @since DOM Level 3
 */
public interface TypeInfo {
    /**
     *  The name of a type declared for the associated element or attribute, 
     * or <code>null</code> if undeclared. "name" seems too generic and may 
     * conflict. shoud we rename it?
     */
    public String getName();

    /**
     *  The namespace of the type declared for the associated element or 
     * attribute or <code>null</code> if the element does not have 
     * declaration or if no namespace information is available. "namespace" 
     * seems too generic and may conflict. shoud we rename it?
     */
    public String getNamespace();

}
